@@ -8,6 +8,9 @@ class _request_param_type(enum.Enum):
     header = "header"
     query = "query"
     body = "body"
+    form = "form"
+    form_url_encoded = "x-www-form-urlencoded"
+    file = "file"
 
 class BaseParams():
     """Define parameter implicitly as a Header, Path, Query, Body
@@ -66,7 +69,7 @@ class BaseParams():
         self._type = _type
     
     def __repr__(self) -> str:
-        return str(self.default)
+        return f"<{self._type.value.upper()} : {self.default}>"
 
 class Header(BaseParams):
     def __init__(
@@ -224,4 +227,121 @@ class Body(BaseParams):
             _type = _request_param_type.body,
             **extra
         )
-        self.pydantic_model = pydantic_model
\ No newline at end of file
+        self.pydantic_model = pydantic_model
+
+class Form(BaseParams):
+    def __init__(
+        self,
+        default: Any,
+        *,
+        alias: Optional[str] = None,
+        title: Optional[str] = None,
+        description: Optional[str] = None,
+        gt: Optional[float] = None,
+        ge: Optional[float] = None,
+        lt: Optional[float] = None,
+        le: Optional[float] = None,
+        min_length: Optional[int] = None,
+        max_length: Optional[int] = None,
+        regex: Optional[str] = None,
+        example: Any = Undefined,
+        examples: Optional[Dict[str, Any]] = None,
+        deprecated: Optional[bool] = None,
+        **extra: Any
+    ) -> None:
+        super().__init__(
+            default=default,
+            alias=alias,
+            title=title,
+            description=description,
+            gt=gt,
+            ge=ge,
+            lt=lt,
+            le=le,
+            min_length=min_length,
+            max_length=max_length,
+            regex=regex,
+            example=example,
+            examples=examples,
+            deprecated=deprecated,
+            _type = _request_param_type.form,
+            **extra
+        )
+
+class FormURLEncoded(BaseParams):
+    def __init__(
+        self,
+        default: Any,
+        *,
+        alias: Optional[str] = None,
+        title: Optional[str] = None,
+        description: Optional[str] = None,
+        gt: Optional[float] = None,
+        ge: Optional[float] = None,
+        lt: Optional[float] = None,
+        le: Optional[float] = None,
+        min_length: Optional[int] = None,
+        max_length: Optional[int] = None,
+        regex: Optional[str] = None,
+        example: Any = Undefined,
+        examples: Optional[Dict[str, Any]] = None,
+        deprecated: Optional[bool] = None,
+        **extra: Any
+    ) -> None:
+        super().__init__(
+            default=default,
+            alias=alias,
+            title=title,
+            description=description,
+            gt=gt,
+            ge=ge,
+            lt=lt,
+            le=le,
+            min_length=min_length,
+            max_length=max_length,
+            regex=regex,
+            example=example,
+            examples=examples,
+            deprecated=deprecated,
+            _type = _request_param_type.form_url_encoded,
+            **extra
+        )
+
+class File(BaseParams):
+    def __init__(
+        self,
+        default: Any,
+        *,
+        alias: Optional[str] = None,
+        title: Optional[str] = None,
+        description: Optional[str] = None,
+        gt: Optional[float] = None,
+        ge: Optional[float] = None,
+        lt: Optional[float] = None,
+        le: Optional[float] = None,
+        min_length: Optional[int] = None,
+        max_length: Optional[int] = None,
+        regex: Optional[str] = None,
+        example: Any = Undefined,
+        examples: Optional[Dict[str, Any]] = None,
+        deprecated: Optional[bool] = None,
+        **extra: Any
+    ) -> None:
+        super().__init__(
+            default=default,
+            alias=alias,
+            title=title,
+            description=description,
+            gt=gt,
+            ge=ge,
+            lt=lt,
+            le=le,
+            min_length=min_length,
+            max_length=max_length,
+            regex=regex,
+            example=example,
+            examples=examples,
+            deprecated=deprecated,
+            _type = _request_param_type.file,
+            **extra
+        )
\ No newline at end of file
