@@ -1,9 +1,11 @@
 from typing import Union, Any
 
-from .fields import Path, Header, Query, Body
+from .fields import Path, Header, Query, Body, Form, FormURLEncoded, File
 
-_ParamsClass = [Header, Query, Path, Body]
-ParamsType = Union[Header, Query, Path, Body]
+_ParamsClasses = (Path, Header, Query, Body, Form, FormURLEncoded, File)
+ParamsType = Union[Path, Header, Query, Body, Form, FormURLEncoded, File]
+_FormClasses = (Form, FormURLEncoded, File)
+FormType = Union[Form, FormURLEncoded, File]
 
 class ParamSignature():
     def __init__(
