@@ -1,14 +1,15 @@
-from collections import defaultdict
 import json
-import os, enum
+import os
+import enum
 import time
+from collections import defaultdict
 from typing import Any, Callable, Dict, Mapping, List, Tuple, Union, Optional
 from flask import Blueprint, Flask, jsonify
 from flask.scaffold import _sentinel
 from pydantic import BaseModel, create_model
 
 from .flask_swagger_ui import get_swaggerui_blueprint
-from ..params import ParamsType, Header, Path, Query, Body
+from ..params import ParamsType, FormType, ParamSignature, Header, Path, Query, Body, Form, FormURLEncoded, File
 from ..routing import APIRouter, EndpointDefinition
 
 
@@ -115,7 +116,7 @@ class SwaggerGenerator(Blueprint):
                             self.template["components"]["schemas"].update(param_definition_schema)                        
                         
                         ## define body schema
-                        body_schema = self.generate_request_body_schema(ep.rule.replace("/","-"), ep.paired_params)
+                        body_schema = self.generate_body_json_schema(ep.rule.replace("/","-"), ep.paired_params)
                         if body_schema:
                             if "definitions" in body_schema:
                                 definitions = body_schema.pop("definitions")
@@ -127,6 +128,26 @@ class SwaggerGenerator(Blueprint):
                                     }
                                 }
                             }
+                        
+                        ## define body form, form-urlencoded, file
+                        for content_type, generate_schema in {
+                            "form-data": self.generate_body_form_schema,
+                            "x-www-form-urlencoded": self.generate_body_form_urlencoded_schema,
+                            "multipart/form-data": self.generate_body_file_schema
+                        }.items():
+                            body_schemas = generate_schema(ep.rule.replace("/","-"), ep.paired_params)
+                            if body_schemas:
+                                for body_schema in body_schemas:
+                                    if "definitions" in body_schema:
+                                        definitions = body_schema.pop("definitions")
+                                        self.template["components"]["schemas"].update(definitions)
+                                    self.template["paths"][ep.rule][ep.method]["requestBody"] = {
+                                        "content":{
+                                            content_type:{
+                                                "schema": body_schema
+                                            }
+                                        }
+                                    }
         if self.additional_path:
             self.template["paths"].update(self.additional_path)
         if self.additional_components:
@@ -135,7 +156,7 @@ class SwaggerGenerator(Blueprint):
             self.template["components"]["schemas"] = self.additional_components_schema
         return self.template
     
-    def generate_parameter_sub_schema(self, key, param_object):
+    def generate_parameter_sub_schema(self, key: str, param_object: ParamsType):
         pydantic_model = create_model(
             key,
             **{
@@ -171,7 +192,7 @@ class SwaggerGenerator(Blueprint):
                 schemas.append(schema)
         return schemas, definitions
     
-    def generate_request_body_schema(self, name, paired_params):
+    def generate_body_json_schema(self, name, paired_params):
         preschema = {}      
         lk = ""
         for k, p in paired_params.items():
@@ -191,6 +212,39 @@ class SwaggerGenerator(Blueprint):
             else:
                 ss = create_model(name, **preschema)
             return ss.schema(ref_template="#/components/schemas/{model}")
+
+    def _generate_form_schema(
+            self,
+            name: str,
+            paired_params: Dict[str, ParamSignature],
+            params_type: FormType
+        ):
+        all_forms = []
+        for k, p in paired_params.items():
+            po = p.param_object
+            if type(po) == params_type:
+                ss = create_model(
+                    name+"_"+po._type.value,
+                    **{k: (Any, p._default)}
+                )
+                all_forms.append(
+                    ss.schema(ref_template="#/components/schemas/{model}")
+                )
+        return all_forms
+    
+    def generate_body_form_schema(self, name, paired_params):
+        return self._generate_form_schema(name, paired_params, Form)
+
+    def generate_body_form_urlencoded_schema(self, name, paired_params):
+        return self._generate_form_schema(name, paired_params, FormURLEncoded)
+
+    def generate_body_file_schema(self, name, paired_params):
+        body_form = self._generate_form_schema(name, paired_params, File)
+        for b in body_form:
+            b["properties"][
+                list(b["properties"].keys())[0]
+            ]["format"] = "binary"
+        return body_form
     
     def get_schema_dtype(self, dtype):
         schema_data_type = {
